# SPDX-License-Identifier: Apache-2.0
# SPDX-FileCopyrightText: 2025 - 2026 BMO Soluciones, S.A.
"""Validators for planilla business logic."""

from coati_payroll.vistas.planilla.validators.planilla_validators import PlanillaValidator

__all__ = ["PlanillaValidator"]
